@@ -61,9 +61,9 @@ class Client(object):
 		return (Client(addr=host, port=port, TLS=TLS, disp_type='web', TLS_check_cert=TLS_check_cert), resource)
 	
 	@staticmethod
-	def request_url(url, method='GET', body=None, TLS_check_cert=True, extra_headers={}):
+	def request_url(url, method='GET', body=None, TLS_check_cert=True, include_response_headers=False, extra_headers={}):
 		c, r = Client.from_url(url, TLS_check_cert=TLS_check_cert)
-		return c.request_web(resource=r, method=method, body=body, extra_headers=extra_headers)
+		return c.request_web(resource=r, method=method, body=body, include_response_headers=include_response_headers, extra_headers=extra_headers)
 	
 	def connect_socket(self):
 		'''creates a socket connection to the server'''
@@ -93,23 +93,26 @@ class Client(object):
 		sock.shutdown(socket.SHUT_RDWR)
 		sock.close()
 	
-	def request_web(self, resource='/', method='GET', body=None, extra_headers={}):
+	def request_web(self, resource='/', method='GET', body=None, include_response_headers=False, extra_headers={}):
 		'''makes a web request and returns the body of the response'''
 		ret = []
 		ret_event = threading.Event()
-		def req_callback(body, code, ret=ret, ret_event=ret_event):
-			ret.append((body, code))
+		def req_callback(body, code, headers, ret=ret, ret_event=ret_event, include_response_headers=include_response_headers):
+			if include_response_headers:
+				ret.append((body, code, headers))
+			else:
+				ret.append((body, code))
 			ret_event.set()
-		self.request_web_async(req_callback, resource=resource, method=method, body=body, extra_headers=extra_headers)
+		self.request_web_async(req_callback, resource=resource, method=method, body=body, include_response_headers=True, extra_headers=extra_headers)
 		ret_event.wait()
 		return ret[0]
 
-	def request_web_async(self, callback, resource='/', method='GET', body=None, timeout=None, extra_headers={}):
+	def request_web_async(self, callback, resource='/', method='GET', body=None, include_response_headers=False, timeout=None, extra_headers={}):
 		'''makes a web request using the raw socket and returns the body of the response'''
 		sock = self.connect_socket()
 		# buf = b''
 
-		req_handler = WebRequestHandler(sock, (self.addr, self.port), None, callback, timeout=timeout, is_client=True, client_resource=resource, client_body=body, client_method=method, client_host=self.addr, add_headers=extra_headers)
+		req_handler = WebRequestHandler(sock, (self.addr, self.port), None, callback, timeout=timeout, is_client=True, client_resource=resource, client_body=body, client_method=method, client_host=self.addr, client_include_response_headers=include_response_headers, add_headers=extra_headers)
 		req_handler.handle_connection()
 		# # # # #TODO: figure out code reuse strategy between here and WebRequestHandler
 		# # # # def recv_until(terminator=b'\r\n', recv_size=128, sock=sock, buf=buf):
