@@ -8,7 +8,15 @@ import traceback
 import socket
 
 def parse_headers(headers):
-	return dict([tuple(l.split(': ',1)) for l in headers.split('\r\n') if ': ' in l])
+	ret = {}
+	for t in [tuple(l.split(': ',1)) for l in headers.split('\r\n') if ': ' in l]:
+		# if cookie name is already used, append it with a comma as described in RFC 2616 section 4.2 - https://www.w3.org/Protocols/rfc2616/rfc2616-sec4.html#sec4.2
+		# this allows the multiple headers to be represented in a python dictionary without special cases of lists, and clients/servers following the spec should work with this rule
+		if t[0] in ret:
+			ret[t[0]] = ret[t[0]] + ',' + t[1]
+		else:
+			ret[t[0]] = t[1]
+	return ret
 
 class WebRequestHandlingException(Exception):
 	'''base class for all exceptions related to web requests'''
@@ -33,7 +41,7 @@ class IncorrectRequestSyntax(WebRequestHandlingException):
 class WebRequestHandler(object):
 	'''handles requests by identifying function based on the URL, then dispatching the request to the appropriate function'''
 	#TODO: figure out if host=None works from external to network
-	def __init__(self, clientsocket, address, client_id, request_handler, timeout=None, is_client=False, client_resource=None, client_body=None, client_method=None, client_host=None, auth_handler=None, add_headers={}):
+	def __init__(self, clientsocket, address, client_id, request_handler, timeout=None, is_client=False, client_resource=None, client_body=None, client_method=None, client_host=None, client_include_response_headers=False, auth_handler=None, add_headers={}):
 		self.log_handler = init_logger(__name__)
 		self.clientsocket = clientsocket
 		self.address = address
@@ -44,6 +52,7 @@ class WebRequestHandler(object):
 		self.client_body = client_body
 		self.client_method = client_method
 		self.client_host = client_host
+		self.client_include_response_headers = client_include_response_headers
 		self.auth_handler = auth_handler
 		self.add_headers = add_headers
 		self.clientsocket.settimeout(timeout)
@@ -60,7 +69,10 @@ class WebRequestHandler(object):
 			self.send()
 			self.recv()
 			if self.is_received:
-				self.request_handler(self.body, self.code)
+				if self.client_include_response_headers:
+					self.request_handler(self.body, self.code, self.headers)
+				else:
+					self.request_handler(self.body, self.code)
 
 	def recv(self):
 		try:
